Lua_TeamMemberItem = class("Lua_TeamMemberItem", Lua_ListCell);
function Lua_TeamMemberItem:ctor(p)
	self:superCall("ctor", p, "TeamMemberItem_skin");
end

function Lua_TeamMemberItem:buildShowItem()
	self:superCall("buildShowItem"); 

	self.headIconItem = Lua_HeadIconItem.new(self.content);
	self.headIconItem:setDepth(5);
	self.headIconItem:setLocation(-287, 5, 0);

	self.bg.clickScale = false;
	self.bg:addClickFuntion(self, self.onBgClick);
	self.kickBtn:addClickFuntion(self,self.onKickClick);

	self:addTimer("team_match", 0.2, self, self.onMathTime);

	self:addLuaEvent("TEAM_MATCH_NUMBER", self, self.onTeamMatchNumber);
end

function Lua_TeamMemberItem:setDepth(val)
	self:superCall("setDepth", val);

	self.bg:setDepth(val);
	self.nameTxt:setDepth(val + 3);
	self.careerTxt:setDepth(val + 3);
	self.lvTxt:setDepth(val + 3);
	self.statueTxt:setDepth(val + 3);
	self.leaderTxt:setDepth(val + 9);
	self.leaderSp:setDepth(val + 8);
	self.kickBtn:setDepth(val + 4);
end

function Lua_TeamMemberItem:onMathTime()
	if self.matchCountDown == true then
		local pt = getTime() - DataCenter.teamData.matchStartTime;
		local leftTime = getConfig({"team", "mateout_tick"}) - pt - DataCenter.teamData.matchTime;
		leftTime = math.floor(leftTime);
		if leftTime <= 0 then
			leftTime = 0;
		end
		self.lvTxt.text = LanUtil.getValue(122213).. LanUtil.formateStr(LanUtil.getValue(122257), tostring(leftTime));
	end
end

function Lua_TeamMemberItem:onTeamMatchNumber(num)
	if self._data ~= nil and self._data.role_id == 0 and DataCenter.teamData.isMatch == true then
		local td = DataCenter.teamData;
		self.lvTxt.text = LanUtil.getValue(122213).."("..LanUtil.formateStr(LanUtil.getValue(122270), tostring(td.mate_amount))..")";
	end
end

function Lua_TeamMemberItem:setData(data)
	self._data = data;
	self.matchCountDown = false;

	if self._data.role_id == 0 then
		self.headIconItem:setEnable(false);
		self.noneObj:SetActive(false);
		self.nameTxt:setEnable(false);
		self.careerTxt:setEnable(false);
		self.statueTxt:setEnable(false);
		self.leaderTxt:setEnable(false);
		self.leaderSp:setEnable(false);
		self.kickBtn:setEnable(false);
		
		if DataCenter.teamData.isMatch == true then
			if DataCenter.teamData:canMathPlayerCopy() then
				self.matchCountDown = true;
			end
			self.lvTxt.text = LanUtil.getValue(122213);
			self.lvTxt:setLocation(-225, 5, 0);
			self.noneObj:SetActive(true);

			self:onTeamMatchNumber();
		else
			self.lvTxt.text = LanUtil.getValue(20);
			self.lvTxt:setLocation(0, 0, 0);
			self.noneObj:SetActive(false);
		end
	else
		self.headIconItem:setEnable(true);
		self.noneObj:SetActive(false);
		self.nameTxt:setEnable(true);
		self.careerTxt:setEnable(true);
		self.statueTxt:setEnable(true);
		self.kickBtn:setEnable(true);

		self.lvTxt:setLocation(-83, -15, 0);
		self.nameTxt.text = data.role_name;
		self.careerTxt.text = Lua_ThingDefine.getJobName(data.role_career, data.profession);
		self.lvTxt.text = LanUtil.formateStr(LanUtil.getValue(122227),tostring(data.role_level));

		if isHeadReplaceOpen() then
			if data.head_frame ~= nil and data.head_frame ~= 0 then
				self.headIconItem:setData(data.role_career, data.role_head, DataCenter.roleData:getHeadFrame(data.head_frame));
			else
				self.headIconItem:setData(data.role_career, data.role_head, nil);
			end
		else
			if data.head_frame ~= nil and data.head_frame ~= 0 then
				self.headIconItem:setData(data.role_career, data.profession, DataCenter.roleData:getHeadFrame(data.head_frame));
			else
				self.headIconItem:setData(data.role_career, data.profession, nil);
			end
		end

		if DataCenter.teamData.hasTeam == false then--没有队伍
			self.leaderTxt:setEnable(false);
			self.leaderSp:setEnable(false);
			self.kickBtn:setEnable(false);
			self.statueTxt:setEnable(false);
		else
			if data.isLeader == true then--队长
				self.leaderTxt:setEnable(true);
				self.leaderSp:setEnable(true);
				if data.role_id == DataCenter.roleData.roleId then
					self.kickBtn:setEnable(true);
					self.kickBtn.label = LanUtil.getValue(122231);
				else
					self.kickBtn:setEnable(false);
				end
			else--队员
				self.leaderTxt:setEnable(false);
				self.leaderSp:setEnable(false);
				if data.role_id == DataCenter.roleData.roleId then
					self.kickBtn:setEnable(true);
					self.kickBtn.label = LanUtil.getValue(122231);
				else
					if DataCenter.teamData.amILeader == true then
						self.kickBtn:setEnable(true);
						self.kickBtn.label = LanUtil.getValue(122232);
					else
						self.kickBtn:setEnable(false);
					end
				end
			end

			if data.role_id == DataCenter.roleData.roleId then
				self.statueTxt:setEnable(false);
			else
				self.statueTxt:setEnable(true);
				if data.online_flag == 1 then
					if data.nearby == false then
						self.statueTxt.text = Lua_ColorDefine.colorStr(LanUtil.getValue(122210), Lua_ColorDefine.RED_STR);
					else
						self.statueTxt.text = Lua_ColorDefine.colorStr(LanUtil.getValue(122209), Lua_ColorDefine.GREEN_STR);
					end
				else
					self.statueTxt.text = Lua_ColorDefine.colorStr(LanUtil.getValue(122211), Lua_ColorDefine.GRAY_STR);
				end
			end
		end
	end
end

function Lua_TeamMemberItem:onKickClick(go)
	if self._data.role_id == 0 then
		return;
	end

	if self._data.role_id == DataCenter.roleData.roleId then -- 退队
		sendMsg(10100306);
		return;
	end

	if DataCenter.teamData.amILeader == true then -- 踢出队伍
		local cmd = ProtoPublic_pb.Proto10100304();
		cmd.role_id = self._data.role_id;
		sendMsg(10100304, cmd);
	end
end

function Lua_TeamMemberItem:onBgClick(go)
	if self._data.role_id == 0 or self._data.role_id == DataCenter.roleData.roleId then
		return;
	end

	if DataCenter.teamData.amILeader == true then
		local menuTypes = Array();
		menuTypes:add(Lua_MenuPopListData.new(Lua_MenuPopListData.BTN_CHECK_INFO, self._data.role_id));
		menuTypes:add(Lua_MenuPopListData.new(Lua_MenuPopListData.BTN_ADD_FRIEND,self._data.role_id));
		menuTypes:add(Lua_MenuPopListData.new(Lua_MenuPopListData.BTN_CHANGE_TEAM_LEADER,self._data.role_id));
		Lua_WindowUtil.openWin("Lua_MenuPopListWindow",WinParam.ACTION_OPEN,menuTypes);
	else
		local menuTypes = Array();
		menuTypes:add(Lua_MenuPopListData.new(Lua_MenuPopListData.BTN_CHECK_INFO, self._data.role_id));
		menuTypes:add(Lua_MenuPopListData.new(Lua_MenuPopListData.BTN_ADD_FRIEND,self._data.role_id));
		Lua_WindowUtil.openWin("Lua_MenuPopListWindow",WinParam.ACTION_OPEN,menuTypes);
	end
end